BlockInfo

Struct BlockInfo 

pub struct BlockInfo { /* private fields */ }
Ethereum block at which a quote was computed.

Quotes are only valid for the block at which they were produced. Conditions may have changed by the time you submit the transaction.

Implementations

Source

impl BlockInfo

pub fn number(&self) -> u64

The block number.

pub fn hash(&self) -> &str

The block hash as a hex string (e.g. "0xabcd...").

pub fn timestamp(&self) -> u64

The block timestamp in Unix seconds.