pub struct FeeBreakdown { /* private fields */ }Expand description
Breakdown of fees applied to the swap output by the on-chain FeeCalculator.
All amounts are absolute values in output token units.
Implementations
Sourceimpl FeeBreakdown
impl FeeBreakdown
Sourcepub fn router_fee(&self) -> &BigUint
pub fn router_fee(&self) -> &BigUint
Router protocol fee (fee on output + router’s share of client fee).
Sourcepub fn client_fee(&self) -> &BigUint
pub fn client_fee(&self) -> &BigUint
Client’s portion of the fee (after the router takes its share).
Sourcepub fn max_slippage(&self) -> &BigUint
pub fn max_slippage(&self) -> &BigUint
Maximum slippage: (amount_out - router_fee - client_fee) * slippage.
Sourcepub fn min_amount_received(&self) -> &BigUint
pub fn min_amount_received(&self) -> &BigUint
Minimum amount the user receives on-chain. Equal to amount_out - router_fee - client_fee - max_slippage.