pub struct Route { /* private fields */ }Expand description
An ordered sequence of swaps that together execute a complete token swap.
For multi-hop routes the output of each Swap is the input of the next.
Implementations